==> apache-cxf-3.6.9-src.zip: apache-cxf-3.6.9-src/rt/frontend/jaxws/src/main/java/org/apache/cxf/jaxws/context/WebServiceContextResourceResolver.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.cxf.jaxws.context;

import java.io.InputStream;

import javax.annotation.Resource;
import javax.xml.ws.WebServiceContext;

import org.apache.cxf.Bus;
import org.apache.cxf.common.injection.NoJSR250Annotations;
import org.apache.cxf.resource.ResourceManager;
import org.apache.cxf.resource.ResourceResolver;

@NoJSR250Annotations(unlessNull = "bus")
public class WebServiceContextResourceResolver implements ResourceResolver {

    Bus bus;

    public WebServiceContextResourceResolver() {
    }

    public WebServiceContextResourceResolver(Bus b) {
        setBus(b);
    }

    @Resource
    public final void setBus(Bus b) {
        bus = b;
        if (bus != null
            && bus.getExtension(ResourceManager.class) != null) {
            bus.getExtension(ResourceManager.class).addResourceResolver(this);
        }
    }



    public final InputStream getAsStream(final String string) {
        return null;
    }

    public final <T> T resolve(final String string, final Class<T> clz) {
        if (WebServiceContext.class.isAssignableFrom(clz)) {
            return clz.cast(new WebServiceContextImpl());
        }
        return null;
    }
}

==> apache-cxf-4.0.10-src.zip: apache-cxf-4.0.10-src/rt/frontend/jaxws/src/main/java/org/apache/cxf/jaxws/context/WebServiceContextResourceResolver.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.cxf.jaxws.context;

import java.io.InputStream;

import jakarta.annotation.Resource;
import jakarta.xml.ws.WebServiceContext;
import org.apache.cxf.Bus;
import org.apache.cxf.common.injection.NoJSR250Annotations;
import org.apache.cxf.resource.ResourceManager;
import org.apache.cxf.resource.ResourceResolver;

@NoJSR250Annotations(unlessNull = "bus")
public class WebServiceContextResourceResolver implements ResourceResolver {

    Bus bus;

    public WebServiceContextResourceResolver() {
    }

    public WebServiceContextResourceResolver(Bus b) {
        setBus(b);
    }

    @Resource
    public final void setBus(Bus b) {
        bus = b;
        if (bus != null
            && bus.getExtension(ResourceManager.class) != null) {
            bus.getExtension(ResourceManager.class).addResourceResolver(this);
        }
    }



    public final InputStream getAsStream(final String string) {
        return null;
    }

    public final <T> T resolve(final String string, final Class<T> clz) {
        if (WebServiceContext.class.isAssignableFrom(clz)) {
            return clz.cast(new WebServiceContextImpl());
        }
        return null;
    }
}
